@@ -67,7 +67,7 @@ GET_LOCATION = """
                             organizationId,
                             organization{id, name},
                             merakiApFloors{id, apFloors, floorName, createdAt},
-                            floors{id, buildingId,number, name, sqm, floorplanURL, rotation, neCorner, swCorner},
+                            floors{id, buildingId, number, name, capacity, sqm, floorplanURL, rotation, neCorner, swCorner},
                             rentPriceSQM,
                             currency,
                             area,
